@@ -9,18 +9,18 @@
 #' @param a integer or vector. A integer or vecter to decide the additive
 #' effects of which QTL will be considered in this design matrix. If
 #' a=TRUE, the additive effect of all QTLs will be considered. If
-#' a=0, no additive effect will be considered.
+#' a=FALSE, no additive effect will be considered.
 #' @param d integer or vector. A integer or vecter to decide the dominant
 #' effects of which QTL will be considered in this design matrix. If
 #' d=TRUE, the dominant effect of all QTLs will be considered.If
-#' d=0, no dominant effect will be considered.
+#' d=FALSE, no dominant effect will be considered.
 #' @param aa vector or matrix. The additive-by-additive interaction. Tow
 #' format can be used in this parameter. One format is vector, in which
 #' every two elements indicate a combination of additive-by-additive
 #' interaction. The other format is a 2*i matrix, where i is the number
 #' of combination of interaction, and each column indicates the two
 #' interacting QTL. Besides, if aa=TRUE, all combinations of
-#' additive-by-additive interaction will be considered. If aa=0, no
+#' additive-by-additive interaction will be considered. If aa=FALSE,, no
 #' additive-by-additive interaction will be considered.
 #' @param dd vector or matrix. The dominant-by-dominant interaction. The
 #' format is the same as that in aa.
@@ -60,7 +60,7 @@
 #' @examples
 #' D.make(4, d = c(1,3,4), aa = c(1,2,2,3), dd = c(1,3,1,4), ad = c(1,2,2,1,2,3,3,4))
 #' D.make(5, type = "BC", a = c(1,3,4,5), aa = c(1,2,3,4,4,5))
-D.make <- function(nQTL, type = "RI", a = TRUE, d = TRUE, aa = 0, dd = 0, ad = 0){
+D.make <- function(nQTL, type = "RI", a = TRUE, d = TRUE, aa = FALSE, dd = FALSE, ad = FALSE){
 
   if(!is.numeric(nQTL) | length(nQTL) != 1 | min(nQTL) < 0){
     stop("Parameter nQTL error, please input a positive integer.", call. = FALSE)
@@ -89,6 +89,7 @@ D.make <- function(nQTL, type = "RI", a = TRUE, d = TRUE, aa = 0, dd = 0, ad = 0
       stop("Effects setting error, please check the parameters of effects.", call. = FALSE)
     }
   } else {a <- NULL}
+
   if(!0 %in% d){
     if("TRUE" %in% as.character(d)){d <- 1:nQTL}
     d <- c(d)
